@@ -5,4 +5,6 @@ from .effect_blank import EffectBlank
 from .effect_static import EffectStatic
 from .effect_free import EffectFree
 from .effect_ma import EffectMA
-from .effect_ar import EffectAR
\ No newline at end of file
+from .effect_ar import EffectAR
+from .effect_matern import EffectMatern
+from .effect_kernel import EffectKernel
\ No newline at end of file
